%% Data function and exact solution
D   = @(x,varargin) ones(size(x));   % Heat conductivity
UEX = @(x) sin(pi*x);                % Exact solution   
F   = @(x,varargin) pi*pi*UEX(x);    % Right-hand side source term
N = 5;
Ns = [5 round(10.^(1:.2:3))];
errs = zeros(length(Ns), 1);
for i = 1:length(Ns)
  N = Ns(i);
  
  %% Initialize mesh
  Coordinates = transpose(linspace(0,1,N+1));

  %% Compute stiffness matrix and load vector
  A = assemMat_LFE(Coordinates,@STIMA_Heat_LFE,gauleg(0,1,2),D);
  L = assemLoad_LFE(Coordinates,gauleg(0,1,2),F);

  %% Incorporate Dirichlet boundary data
  FreeDofs = 2:length(L)-1;

  %% Solve the linear system
  U = zeros(length(L),1);
  U(FreeDofs) = A(FreeDofs,FreeDofs)\L(FreeDofs);

  %% Compute L2-error
  errs(i) = L2Err_LFE(Coordinates,U,gauleg(0,1,2),UEX);


  %% Generate figure
  if N == 5
    figure(1)
    plot_LFE(Coordinates, U)
    hold on;
    plot(linspace(0,1,500),UEX(linspace(0,1,500)),'r--');
    hold off;
    title('{\bf 1D Finite element solver}')
    legend('FE solution','Exact solution')
    
    fprintf('The L2-error is %1.2E\n',errs(i));
  end
end

figure(2)
loglog(Ns, errs)
xlabel('N')
ylabel('L^2 error')
